From f61ca3a918c6ad7f1a7b80072e227a9ef622bca5 Mon Sep 17 00:00:00 2001
From: Matt Oliver <protogonoi@gmail.com>
Date: Fri, 7 Mar 2014 15:55:37 +1100
Subject: [PATCH] Fix C89 compatibility for native msvc compile support.

---
 common/deblock.c     | 2 +-
 common/frame.c       | 4 ++--
 common/opencl.c      | 7 +++----
 common/threadpool.c  | 2 +-
 common/win32thread.c | 9 ++++++---
 encoder/encoder.c    | 9 +++++----
 encoder/lookahead.c  | 3 ++-
 7 files changed, 20 insertions(+), 16 deletions(-)

diff --git a/common/deblock.c b/common/deblock.c
index 47b604f..74d3fcb 100644
--- a/common/deblock.c
+++ b/common/deblock.c
@@ -606,10 +606,10 @@ void x264_macroblock_deblock( x264_t *h )
     int intra_cur = IS_INTRA( h->mb.i_type );
     int qp = h->mb.i_qp;
     int qpc = h->mb.i_chroma_qp;
+    uint8_t( *bs )[8][4] = h->mb.cache.deblock_strength;
     if( (h->mb.i_partition == D_16x16 && !h->mb.i_cbp_luma && !intra_cur) || qp <= qp_thresh )
         return;
 
-    uint8_t (*bs)[8][4] = h->mb.cache.deblock_strength;
     if( intra_cur )
     {
         memset( &bs[0][1], 3, 3*4*sizeof(uint8_t) );
diff --git a/common/frame.c b/common/frame.c
index 4b4a69f..32c73c1 100644
--- a/common/frame.c
+++ b/common/frame.c
@@ -548,11 +548,11 @@ void x264_frame_expand_border( x264_t *h, x264_frame_t *frame, int mb_y )
         int height = (pad_bot ? 16*(h->mb.i_mb_height - mb_y) >> SLICE_MBAFF : 16) >> v_shift;
         int padh = PADH;
         int padv = PADV >> v_shift;
+        pixel *pix;
+        int starty = 16 * mb_y - 4 * !b_start;
         // buffer: 2 chroma, 3 luma (rounded to 4) because deblocking goes beyond the top of the mb
         if( b_end && !b_start )
             height += 4 >> (v_shift + SLICE_MBAFF);
-        pixel *pix;
-        int starty = 16*mb_y - 4*!b_start;
         if( SLICE_MBAFF )
         {
             // border samples for each field are extended separately
diff --git a/common/opencl.c b/common/opencl.c
index 9e5e794..12a27f4 100644
--- a/common/opencl.c
+++ b/common/opencl.c
@@ -122,13 +122,12 @@ static int x264_detect_switchable_graphics( void );
 static cl_program x264_opencl_cache_load( x264_t *h, const char *dev_name, const char *dev_vendor, const char *driver_version )
 {
     /* try to load cached program binary */
-    FILE *fp = x264_fopen( h->param.psz_clbin_file, "rb" );
-    if( !fp )
-        return NULL;
-
     x264_opencl_function_t *ocl = h->opencl.ocl;
     cl_program program = NULL;
     uint8_t *binary = NULL;
+    FILE *fp = x264_fopen( h->param.psz_clbin_file, "rb" );
+    if( !fp )
+        return NULL;
 
     fseek( fp, 0, SEEK_END );
     size_t size = ftell( fp );
diff --git a/common/threadpool.c b/common/threadpool.c
index 6c44cc8..77f98e2 100644
--- a/common/threadpool.c
+++ b/common/threadpool.c
@@ -75,10 +75,10 @@ static void *x264_threadpool_thread( x264_threadpool_t *pool )
 int x264_threadpool_init( x264_threadpool_t **p_pool, int threads,
                           void (*init_func)(void *), void *init_arg )
 {
+    x264_threadpool_t *pool;
     if( threads <= 0 )
         return -1;
 
-    x264_threadpool_t *pool;
     CHECKED_MALLOCZERO( pool, sizeof(x264_threadpool_t) );
     *p_pool = pool;
 
diff --git a/common/win32thread.c b/common/win32thread.c
index 7ad70ed..9837a93 100644
--- a/common/win32thread.c
+++ b/common/win32thread.c
@@ -156,12 +156,13 @@ int x264_pthread_cond_init( x264_pthread_cond_t *cond, const x264_pthread_condat
 
 int x264_pthread_cond_destroy( x264_pthread_cond_t *cond )
 {
+    x264_win32_cond_t *win32_cond;
     /* native condition variables do not destroy */
     if( thread_control.cond_init )
         return 0;
 
     /* non native condition variables */
-    x264_win32_cond_t *win32_cond = cond->ptr;
+    win32_cond = cond->ptr;
     CloseHandle( win32_cond->semaphore );
     CloseHandle( win32_cond->waiters_done );
     x264_pthread_mutex_destroy( &win32_cond->mtx_broadcast );
@@ -173,6 +174,7 @@ int x264_pthread_cond_destroy( x264_pthread_cond_t *cond )
 
 int x264_pthread_cond_broadcast( x264_pthread_cond_t *cond )
 {
+    x264_win32_cond_t *win32_cond;
     if( thread_control.cond_broadcast )
     {
         thread_control.cond_broadcast( cond );
@@ -180,7 +182,7 @@ int x264_pthread_cond_broadcast( x264_pthread_cond_t *cond )
     }
 
     /* non native condition variables */
-    x264_win32_cond_t *win32_cond = cond->ptr;
+    win32_cond = cond->ptr;
     x264_pthread_mutex_lock( &win32_cond->mtx_broadcast );
     x264_pthread_mutex_lock( &win32_cond->mtx_waiter_count );
     int have_waiter = 0;
@@ -230,11 +232,12 @@ int x264_pthread_cond_signal( x264_pthread_cond_t *cond )
 
 int x264_pthread_cond_wait( x264_pthread_cond_t *cond, x264_pthread_mutex_t *mutex )
 {
+    x264_win32_cond_t *win32_cond;
     if( thread_control.cond_wait )
         return !thread_control.cond_wait( cond, mutex, INFINITE );
 
     /* non native condition variables */
-    x264_win32_cond_t *win32_cond = cond->ptr;
+    win32_cond = cond->ptr;
 
     x264_pthread_mutex_lock( &win32_cond->mtx_broadcast );
     x264_pthread_mutex_lock( &win32_cond->mtx_waiter_count );
diff --git a/encoder/encoder.c b/encoder/encoder.c
index 815c6f8..18ea73a 100644
--- a/encoder/encoder.c
+++ b/encoder/encoder.c
@@ -1863,12 +1863,13 @@ static int x264_check_encapsulated_buffer( x264_t *h, x264_t *h0, int start,
     {
         necessary_size *= 2;
         uint8_t *buf = x264_malloc( necessary_size );
+        intptr_t delta;
         if( !buf )
             return -1;
         if( previous_nal_size )
             memcpy( buf, h0->nal_buffer, previous_nal_size );
 
-        intptr_t delta = buf - h0->nal_buffer;
+        delta = buf - h0->nal_buffer;
         for( int i = 0; i < start; i++ )
             h->out.nal[i].p_payload += delta;
 
@@ -1884,6 +1885,7 @@ static int x264_encoder_encapsulate_nals( x264_t *h, int start )
 {
     x264_t *h0 = h->thread[0];
     int nal_size = 0, previous_nal_size = 0;
+    uint8_t *nal_buffer;
 
     if( h->param.nalu_process )
     {
@@ -1905,7 +1907,7 @@ static int x264_encoder_encapsulate_nals( x264_t *h, int start )
     if( x264_check_encapsulated_buffer( h, h0, start, previous_nal_size, necessary_size ) )
         return -1;
 
-    uint8_t *nal_buffer = h0->nal_buffer + previous_nal_size;
+    nal_buffer = h0->nal_buffer + previous_nal_size;
 
     for( int i = start; i < h->out.i_nal; i++ )
     {
@@ -2713,8 +2715,7 @@ reencode:
             if( !h->param.b_cabac )
                 total_bits += bs_size_ue_big( i_skip );
             /* Check for escape bytes. */
-            uint8_t *end = h->param.b_cabac ? h->cabac.p : h->out.bs.p;
-            for( ; last_emu_check < end - 2; last_emu_check++ )
+            for( ; last_emu_check < (h->param.b_cabac ? h->cabac.p : h->out.bs.p) - 2; last_emu_check++ )
                 if( last_emu_check[0] == 0 && last_emu_check[1] == 0 && last_emu_check[2] <= 3 )
                 {
                     slice_max_size -= 8;
diff --git a/encoder/lookahead.c b/encoder/lookahead.c
index a6e861b..cee6fbf 100644
--- a/encoder/lookahead.c
+++ b/encoder/lookahead.c
@@ -126,6 +126,7 @@ static void *x264_lookahead_thread( x264_t *h )
 int x264_lookahead_init( x264_t *h, int i_slicetype_length )
 {
     x264_lookahead_t *look;
+    x264_t *look_h;
     CHECKED_MALLOCZERO( look, sizeof(x264_lookahead_t) );
     for( int i = 0; i < h->param.i_threads; i++ )
         h->thread[i]->lookahead = look;
@@ -144,7 +145,7 @@ int x264_lookahead_init( x264_t *h, int i_slicetype_length )
     if( !h->param.i_sync_lookahead )
         return 0;
 
-    x264_t *look_h = h->thread[h->param.i_threads];
+    look_h = h->thread[h->param.i_threads];
     *look_h = *h;
     if( x264_macroblock_cache_allocate( look_h ) )
         goto fail;
-- 
1.8.4.msysgit.0

